ams.routines.routine.RoutineBase
================================

.. currentmodule:: ams.routines.routine

.. autoclass:: RoutineBase

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~RoutineBase.addConstrs
       
       
          ~RoutineBase.addRParam
       
       
          ~RoutineBase.addService
       
       
          ~RoutineBase.addVars
       
       
          ~RoutineBase.dc2ac
       
       
          ~RoutineBase.disable
       
       
          ~RoutineBase.doc
       
       
          ~RoutineBase.enable
       
       
          ~RoutineBase.export_csv
       
       
          ~RoutineBase.get
       
       
          ~RoutineBase.init
       
       
          ~RoutineBase.run
       
       
          ~RoutineBase.set
       
       
          ~RoutineBase.solve
       
       
          ~RoutineBase.summary
       
       
          ~RoutineBase.unpack
       
       
          ~RoutineBase.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~RoutineBase.class_name
   
   